# Contributing to Fresco
We want to make contributing to this project as easy and transparent as
possible.


## Issues  
We use GitHub issues to track public bugs. 

When you report an issue the more information the better. Here are some things that will help you get an answer faster:

- A *title* as well as a body for the issue.
- A screenshot or video of the problem
- Logcat output, if your app is crashing.
- The format of the affected images (JPEG, PNG, GIF, or WebP)
- Whether the image is an animation
- Where the images are coming from - network, local file, content provider, asset, or resource.
- A snippet of the code in question
- Place code in blocks so that it reads like code:

```
```java (or xml)
your code here
```(terminating backticks)
```

#### Security bugs

Facebook has a [bounty program](https://www.facebook.com/whitehat/) for the safe
disclosure of security bugs. In those cases, please go through the process
outlined on that page and do not file a public issue.

## Pull Requests
We actively welcome your pull requests.

1. Fork the repo and create your branch from `master`. 
2. If you've added code that should be tested, add tests
3. If you've changed APIs, update the documentation. 
4. Ensure the test suite passes. 
5. Make sure your code lints. 
6. If you haven't already, complete the Contributor License Agreement ("CLA").

## Contributor License Agreement ("CLA")
In order to accept your pull request, we need you to submit a CLA. You only need
to do this once to work on any of Facebook's open source projects.

Complete your CLA here: <https://code.facebook.com/cla>.

## Our Development Process
Each pull request is first submitted into Facebook's internal repositories by a
Facebook team member. Once the commit has successfully passed Facebook's internal
test suite, it will be exported back out from Facebook's repository. We endeavour
to do this as soon as possible for all commits.

## Coding Style  
* 2 spaces for indentation rather than tabs
* 100 character line length
* Although officially archived, we still follow the practice of Oracle's 
[Coding Conventions for the Java Programming Language](http://www.oracle.com/technetwork/java/javase/documentation/codeconvtoc-136057.html).

## License
By contributing to Fresco, you agree that your contributions will be licensed
under its BSD license.
